Index: GUI/GUIGlobalMusicSearch.cs
===================================================================
--- GUI/GUIGlobalMusicSearch.cs	(revision 51)
+++ GUI/GUIGlobalMusicSearch.cs	(working copy)
@@ -84,6 +84,7 @@
         private string currentSearchString = string.Empty;
         private SearchGlobals.SearchType currentSearchType = SearchGlobals.SearchType.Contains;
         private int previousSelectedIndex = 0;
+        private static bool _playlistIsCurrent = false;
         #endregion
 
         #region Overrides
@@ -120,6 +121,7 @@
 
         public override bool Init()
         {
+            LoadMPSettings();
             Translation.Init();
             GlobalSearchSettings.Instance().LoadFromFile();
             return Load(GUIGraphicsContext.Skin + @"\GlobalSearch.Music.xml");
@@ -339,19 +341,19 @@
         public static void ClearPlaylist()
         {
             PlayListPlayer playListPlayer = PlayListPlayer.SingletonPlayer;
-            PlayList playList = playListPlayer.GetPlaylist(PlayListType.PLAYLIST_MUSIC);
+            PlayList playList = playListPlayer.GetPlaylist(GetPlaylistType());
             playList.Clear();
         }
 
         public static void AddSongToPlaylist(Song song, bool autoPlayWhenNothingInList)
         {
             PlayListPlayer playListPlayer = PlayListPlayer.SingletonPlayer;
-            PlayList playList = playListPlayer.GetPlaylist(PlayListType.PLAYLIST_MUSIC);
-            PlayListItem _pi = new PlayListItem(song.Title, song.FileName, song.Duration);
+            PlayList playList = playListPlayer.GetPlaylist(GetPlaylistType());
+            PlayListItem _pi = song.ToPlayListItem();
             playList.Add(_pi);
             if ((autoPlayWhenNothingInList) && (!playListPlayer.g_Player.Playing))
             {
-                playListPlayer.CurrentPlaylistType = PlayListType.PLAYLIST_MUSIC;
+                playListPlayer.CurrentPlaylistType = GetPlaylistType();
                 playListPlayer.Play(0);
             }
         }
@@ -370,7 +372,7 @@
         public static void PlayNext(Song song)
         {
             PlayListPlayer playlistPlayer = PlayListPlayer.SingletonPlayer;
-            PlayList playList = playlistPlayer.GetPlaylist(PlayListType.PLAYLIST_MUSIC);
+            PlayList playList = playlistPlayer.GetPlaylist(GetPlaylistType());
 
             int index = Math.Max(playlistPlayer.CurrentSong, 0);
 
@@ -381,18 +383,18 @@
 
             if (playList.Count > 1)
             {
-                PlayListItem _pi = new PlayListItem(song.Title, song.FileName, song.Duration);
+                PlayListItem _pi = song.ToPlayListItem();
                 playList.Insert(_pi, index);
             }
             else
             {
-                playlistPlayer.CurrentPlaylistType = PlayListType.PLAYLIST_MUSIC;
+                playlistPlayer.CurrentPlaylistType = GetPlaylistType();
                 AddSongToPlaylist(song);
             }
 
             if (!playlistPlayer.g_Player.Playing)
             {
-                playlistPlayer.CurrentPlaylistType = PlayListType.PLAYLIST_MUSIC;
+                playlistPlayer.CurrentPlaylistType = GetPlaylistType();
                 playlistPlayer.Play(index);
             }
         }
@@ -400,7 +402,7 @@
         public static void AddAlbumToPlayList(Song song)
         {
             PlayListPlayer playlistPlayer = PlayListPlayer.SingletonPlayer;
-            PlayList playList = playlistPlayer.GetPlaylist(PlayListType.PLAYLIST_MUSIC);
+            PlayList playList = playlistPlayer.GetPlaylist(GetPlaylistType());
             if (GUIUtils.ShowYesNoDialog(GUILocalizeStrings.Get(136), Translation.ClearPlaylist, true))
             {
                 ClearPlaylist();
@@ -527,7 +529,7 @@
         {
             MusicDatabase _mdb = MusicDatabase.Instance;
             PlayListPlayer playListPlayer = PlayListPlayer.SingletonPlayer;
-            PlayList playList = playListPlayer.GetPlaylist(PlayListType.PLAYLIST_MUSIC);
+            PlayList playList = playListPlayer.GetPlaylist(GetPlaylistType());
             Song firstSong = null;
 
             if (GUIUtils.ShowYesNoDialog(GUILocalizeStrings.Get(136), Translation.ClearPlaylist, true))
@@ -541,7 +543,7 @@
                 Song _song = new Song();
                 _mdb.GetSongByFileName(li.Path, ref _song);
 
-                PlayListItem _pi = new PlayListItem(_song.Title, _song.FileName, _song.Duration);
+                PlayListItem _pi = _song.ToPlayListItem();
                 playList.Add(_pi);
 
                 if (firstSong == null)
@@ -552,7 +554,7 @@
 
             if ((firstSong != null) && (!playListPlayer.g_Player.Playing))
             {
-                playListPlayer.CurrentPlaylistType = PlayListType.PLAYLIST_MUSIC;
+                playListPlayer.CurrentPlaylistType = GetPlaylistType();
                 playListPlayer.Play(0);
             }
         }
@@ -631,6 +633,23 @@
             return strLine;
         }
 
+        private void LoadMPSettings()
+        {
+          using (Profile.Settings xmlreader = new Profile.MPSettings())
+          {
+            _playlistIsCurrent = xmlreader.GetValueAsBool("musicfiles", "playlistIsCurrent", true);
+          }
+        }
+
+        private static PlayListType GetPlaylistType()
+        {
+          if (_playlistIsCurrent)
+          {
+            return PlayListType.PLAYLIST_MUSIC;
+          }
+          return PlayListType.PLAYLIST_MUSIC_TEMP;
+        }
+
         #endregion
 
         #region ISetupForm Members
Index: GUI/GUIGlobalMusicSearchDetails.cs
===================================================================
--- GUI/GUIGlobalMusicSearchDetails.cs	(revision 51)
+++ GUI/GUIGlobalMusicSearchDetails.cs	(working copy)
@@ -186,10 +186,6 @@
         GUIUtils.SetProperty("#GlobalSearch.Music.Details.ArtistInfo.Tones", hasArtistInfo ? artistInfo.Tones : string.Empty, true);
         GUIUtils.SetProperty("#GlobalSearch.Music.Details.ArtistInfo.YearsActive", hasArtistInfo ? artistInfo.YearsActive : string.Empty, true);
 
-        PlayListPlayer playlistPlayer = PlayListPlayer.SingletonPlayer;
-        PlayList playList = playlistPlayer.GetPlaylist(PlayListType.PLAYLIST_MUSIC);
-        PlayListItem pli = new PlayListItem(song.Title, song.FileName, song.Duration);
-
         string thumbnail = GetAlbumOrFolderThumb(song);
         if (!string.IsNullOrEmpty(thumbnail))
         {
